{ pkgs, ... }:
{
  # Enable the X11 windowing system
  services.xserver.enable = true;

  services.xserver = {
    extraLayouts.qwerty-fr = {
      description = "QWERTY-fr";
      languages = [ "fr" ];
      symbolsFile = "${pkgs.stdenv.mkDerivation {
          name = "qwerty-fr-keypad";
          src = builtins.fetchGit {
            url = "https://github.com/qwerty-fr/qwerty-fr.git";
            rev = "3a4d13089e8ef016aa20baf6b2bf3ea53de674b8";
          };
          patches = [ ./qwerty-fr-keypad.diff ];
          # TODO This doesn't seem to be applied... it's the whole point of the derivation :(
          installPhase = ''
            runHook preInstall
            mkdir -p $out/linux
            cp $src/linux/us_qwerty-fr $out/linux
            runHook postInstall
          '';
      }}/linux/us_qwerty-fr";
    };
    layout = "qwerty-fr";
    # TODO home.keyboard = null; in home-manager... or something

  };

  # Enable sound
  sound.enable = true;
  hardware.pulseaudio.enable = true;

  services.xserver.displayManager.startx.enable = true;
  services.xserver.windowManager.i3.enable = true;

  users.users.geoffrey. packages = with pkgs; [
    # remote
    tigervnc

    # music
    mpd
    mpc-cli
    ashuffle
    vimpc

    # multimedia common
    gimp
    inkscape
    mpv
    mpvScripts.thumbnail
    libreoffice

    # data management
    freefilesync

    # browsers
    firefox
    qutebrowser

    # fonts
    dejavu_fonts
    twemoji-color-font
    xfce.thunar
    gnome.gedit
    feh
    zathura
    zbar
    zathura
    meld
    python3Packages.magic
    yubikey-touch-detector

    # x11-exclusive
    libgnomekbd # to show keyboard layout
    dunst
    i3lock
    numlockx
    rofi
    rofimoji
    rxvt-unicode
    # TODO urxvt-resize-font-git
    scrot
    simplescreenrecorder
    trayer
    unclutter
    xautolock
    xclip
    lemonbar-xft
    autorandr
    keynav
    sct
    xorg.xinit
    xorg.xbacklight

    alacritty

    # organisation
    rofi-pass # TODO Try autopass.cr
    thunderbird
  ];

  environment.systemPackages = with pkgs; [ pavucontrol ];

}
